# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For the full
# list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
import sys
from datetime import date

if sys.version_info >= (3, 8):
    from importlib import metadata
else:
    import importlib_metadata as metadata

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

project = 'ByteBlower Test Case: Low latency'
copyright = f'{date.today().year!s}, Excentis NV'
author = 'Excentis NV'

# The full version, including alpha/beta/rc tags
release = metadata.version('byteblower-test-cases-low-latency')

# The short X.Y version
# for example take major/minor
version = '.'.join(release.split('.')[:2])

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.intersphinx',
    'sphinx.ext.todo',
    'sphinx.ext.imgmath',
    'sphinx.ext.extlinks',
    'sphinx_rtd_theme',
    'sphinx_tabs.tabs',
    'sphinx-jsonschema',
    'sphinx_tags',
    'sphinx_design',
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
# language = 'en'  # default
# XXX - By default, build using default English
# language = 'nl'

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = [
    '_include/*.rst',
]

# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
# html_theme = 'alabaster'
html_theme = 'sphinx_rtd_theme'
html_theme_options = {
    "logo_only": False,
    "style_external_links": True,
    "style_nav_header_background": "#00aeef"
}

# The name of the Pygments (syntax highlighting) style to use.
# XXX - Changes e.g. background on `code-block`s.
pygments_style = 'sphinx'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

# A list of CSS files. The entry must be a filename string or a tuple
# containing the filename string and the attributes dictionary.
# The filename must be relative to the html_static_path, or a full URI
# with scheme like https://example.org/style.css.
# The attributes is used for attributes of <link> tag.
# It defaults to an empty list.
html_css_files = ['excentis.css']

# If true, “Created using Sphinx” is shown in the HTML footer.
# Default is True.
html_show_sphinx = False

# If true, the reST sources are included in the HTML build as _sources/name.
# The default is True.
html_copy_source = False

# If true (and html_copy_source is true as well), links to the reST sources
# will be added to the sidebar. The default is True.
html_show_sourcelink = False

# A list of paths that contain extra files not directly related to the
# documentation, such as robots.txt or .htaccess. Relative paths are taken
# as relative to the configuration directory. They are copied to the output
# directory. They will overwrite any existing file of the same name.
#
# As these files are not meant to be built, they are automatically excluded
# from source files.
html_extra_path = [
    # NOTE: The extra 'test-cases/low_latency' sub-directory is important
    #       for including this documentation in the ByteBlower Test Framework
    #       "overview" documentation (``byteblower-test-framework-docs``)
    'extra/test-cases/low-latency',
]

# -- Extension configuration -------------------------------------------------

# -- Options for autodoc extension -------------------------------------------

# See Configuration:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#configuration

# See:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autoclass_content
autoclass_content = 'class'  # default
# Other options:
# autoclass_content = 'init'
# autoclass_content = 'both'

# This will separate for example <class>.__init__(self) documentation
# from <class> documentation.
#
# See:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autodoc_class_signature
# autodoc_class_signature = 'mixed'  # default
autodoc_class_signature = 'separated'

# See:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autodoc_default_options
# autodoc_default_options = {
#     'special-members': '__init__, __eq__',
#     'show-inheritance': True,
#     'undoc-members': True,
# }

# See:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autodoc_typehints
# autodoc_typehints = 'signature'  # default
# autodoc_typehints = 'description'
autodoc_typehints = 'both'

# See:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autodoc_typehints_description_target
# autodoc_typehints_description_target = 'all'  # default
# autodoc_typehints_description_target = 'documented'
# Supported since v5.0:
autodoc_typehints_description_target = 'documented_params'

# See:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autodoc_type_aliases
# del autodoc_type_aliases  # default
# autodoc_type_aliases = {
#     'Content': 'byteblower_test_framework._analysis.analyseraggregator.Content',
# }

# See:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autodoc_typehints_format
# autodoc_typehints_format = 'fully-qualified'  # default < v5.0
autodoc_typehints_format = 'short'  # default since v5.0

# See:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autodoc_preserve_defaults
# We keep it to `False` since `const` values are not resolved/documented
# when they are not defined in a public module, no matter whether they
# are "exported" in a public module or not.
autodoc_preserve_defaults = False  # default
# Other options:
# autodoc_preserve_defaults = True

# See:
#   https://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#confval-autodoc_inherit_docstrings
# autodoc_inherit_docstrings = True  # default

# -- Options for intersphinx extension ---------------------------------------
# https://www.sphinx-doc.org/en/master/usage/extensions/intersphinx.html#configuration

# Example configuration for intersphinx: refer to the Python standard library.
intersphinx_mapping = {
    'python': ('https://docs.python.org/3', None),
}

# -- Options for todo extension ----------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/extensions/todo.html#configuration

# If true, `todo` and `todoList` produce output, else they produce nothing.
# todo_include_todos = True  # For development/beta releases!
todo_include_todos = False  # Only for release!

# If this is True, todolist produce output without file path and line, The default is False.
todo_link_only = True  # New in version 1.4

# -- Options for sphinx-tabs extension ----------------------------------------------
# https://sphinx-tabs.readthedocs.io/en/latest/#sphinx-configuration

# By default, tabs can be closed by selecting the open tab. This functionality
# can be disabled using:
sphinx_tabs_disable_tab_closing = True

# By default, the extension loads predefined CSS styles for tabs.
# To disable the CSS from loading, add the following:
# sphinx_tabs_disable_css_loading = True

# -- Options for sphinx-tags extension ----------------------------------------------
# https://sphinx-tags.readthedocs.io/en/latest/configuration.html#config

# Whether to process tags or not. Default: False
tags_create_tags = True

# Customize the title of the tags overview page. Default: "Tags overview"
tags_overview_title = "Topics"

# The title of the tag page, after which the tag is listed. Default: "My tags"
tags_page_title = "Topic"

# Whether to display tags using sphinx-design badges. Default: False
# Requires the sphinx-design extension
tags_create_badges = True

# Colors to use for badges based on tag name. Default: {}
tags_badge_colors = {
    "Introduction": "info",  # Used for "difficulty levels"
    "Intermediate": "info",  # Used for "difficulty levels"
    "L4S": "success",  # Used for highlights
    "LLD": "success",  # Used for highlights
    "Low Latency DOCSIS": "success",  # Used for highlights
    # NOTE: Works, but cumbersome to show that way in the documentation:
    # "protocol:*": "secondary",  # Used as a default value
    # FIXME: "glob" does not work this way:
    # "UDP,TCP": "secondary",  # Used for protocols
    "UDP": "secondary",  # Used for protocols
    "TCP": "secondary",  # Used for protocols
    "TCP Prague": "secondary",  # Used for protocols
    "HTTP": "secondary",  # Used for protocols
    "*": "primary",  # Used as a default value
}
